require(foreign)
require(MASS) #for the glm.nb function
require(plyr)
require(xlsx)
setwd("E:/ConchCruises2016/Data/Revisions/SupportingElectronicMaterials/") 

#load in the appropriate data

dat = read.csv("ECLSP_GLM_2017_RS.csv")

dat$YEAR = factor(dat$Year) #make year into a categorical factor

#the following 8 models, m1 thru m8, estimate the changes in abundance for adults (A). This can be changed to subadults (S) or juveniles (J)

m1 = glm.nb( A ~ YEAR + Length + Channel_line, data = dat, link = log)
s1=summary(m1)
s1

m2 = glm.nb( A ~ YEAR + Channel_line, data = dat, link = log)
s2=summary(m2)
s2

m3 = glm.nb( A ~ YEAR + Length , data = dat, link = log)
s3=summary(m3)
s3

m4 = glm.nb( A ~ Length + Channel_line, data = dat, link = log)
s4=summary(m4)
s4

m5 = glm.nb( A ~ YEAR , data = dat, link = log)
s5=summary(m5)
s5

m6 = glm.nb( A ~ Channel_line, data = dat, link = log)
s6=summary(m6)
s6

m7 = glm.nb( A ~  Length , data = dat, link = log)
s7=summary(m7)
s7

m8 = glm.nb( A ~  1 , data = dat, link = log)
s8=summary(m8)
s8

#abundanceModels_Ads = rbind(s1,s2,s3,s4,s5,s6,s7,s8)

#write.xlsx(abundanceModels_Ads, "ECLSP_Adult_GLM.xlsx")
predictions = read.csv("ECLSP_GLM_Predict_2017_ES.csv")
predictions$YEAR = factor(predictions$Year)

#for each lifestage, the full model is a candidate for best fit (<2 AIC from top), so just stick with it for all cases
predictions$Est_Ads = predict(m1, predictions, type = "response")

#here we consider the predictions of the model for a specific class of conch, adults (A). This can be adjusted to describe Subadults (S) or Juveniles (J)
predictions$Adj_Ads = log(predictions$A + 1) #adjust counts for zero inflation w simple xform
predictions$Adj_PredictA = log(predictions$Est_Ads + 1) #do same xform to predicted


cor.test(predictions$Adj_Ads[1:149], predictions$Adj_PredictA[1:149]) #last row was a dummy to ensure proper year factor used


#Below we describe the effects of location and year on shell lip thickness and shell length using 8 different model iterations, m1 thru m8
LT_SL_Side_Yr = read.csv("ECLSP_Measurements_Side_Yr.csv")
LT_SL_Side_Yr$SIDE = factor(LT_SL_Side_Yr$location..1...bank..2...sound.)
LT_SL_Side_Yr$YEAR = factor(LT_SL_Side_Yr$year)

LT_SL_Side_Yr$SIDE = revalue(LT_SL_Side_Yr$SIDE, c("1" = "Bank", "2" = "Shelf"))

m1 = glm(Thickness ~ SIDE + YEAR +SIDE:YEAR, data = LT_SL_Side_Yr)
s1 = summary(m1)
s1

m2 = glm(Thickness ~ SIDE + YEAR, data = LT_SL_Side_Yr)
s2 = summary(m2)
s2

m3 = glm(Thickness ~ SIDE + SIDE:YEAR, data = LT_SL_Side_Yr)
s3 = summary(m3)
s3

m4 = glm(Thickness ~ YEAR + SIDE:YEAR, data = LT_SL_Side_Yr)
s4 = summary(m4)
s4

m5 = glm(Thickness ~ SIDE:YEAR, data = LT_SL_Side_Yr)
s5 = summary(m5)
s5

m6 = glm(Thickness ~ YEAR, data = LT_SL_Side_Yr)
s6 = summary(m6)
s6

m7 = glm(Thickness ~ SIDE, data = LT_SL_Side_Yr)
s7 = summary(m7)
s7

m8 = glm(Thickness ~ 1, data = LT_SL_Side_Yr)
s8 = summary(m8)
s8

#same thing for Shell length
m1 = glm(Length ~ SIDE + YEAR +SIDE:YEAR, data = LT_SL_Side_Yr)
s1 = summary(m1)
s1

m2 = glm(Length ~ SIDE + YEAR, data = LT_SL_Side_Yr)
s2 = summary(m2)
s2

m3 = glm(Length ~ SIDE + SIDE:YEAR, data = LT_SL_Side_Yr)
s3 = summary(m3)
s3

m4 = glm(Length ~ YEAR + SIDE:YEAR, data = LT_SL_Side_Yr)
s4 = summary(m4)
s4

m5 = glm(Length ~ SIDE:YEAR, data = LT_SL_Side_Yr)
s5 = summary(m5)
s5

m6 = glm(Length ~ YEAR, data = LT_SL_Side_Yr)
s6 = summary(m6)
s6

m7 = glm(Length ~ SIDE, data = LT_SL_Side_Yr)
s7 = summary(m7)
s7

m8 = glm(Length ~ 1, data = LT_SL_Side_Yr)
s8 = summary(m8)
s8

# here we see how the confiscated conch in 2016 compare with those of the bank and sound
dat = read.csv("ECLSP_Confiscated_Comp.csv")
dat$Local = factor(dat$X1bank_2sound_3confs) #make year into a categorical factor

c1 = glm(Length ~ Local, data = dat)
s1 = summary(c1)
s1

c2 = glm(Thickness ~ Local, data = dat)
s2 = summary(c2)
s2
